| Title: | Ridge Regression Parameter Estimation |
|---|---|
| Description: | It is a package that provides alternative approach for finding optimum parameters of ridge regression. This package focuses on finding the ridge parameter value k which makes the variance inflation factors closest to 1, while keeping them above 1 as addressed by Michael Kutner, Christopher Nachtsheim, John Neter, William Li (2004, ISBN:978-0073108742). Moreover, the package offers end-to-end functionality to find optimum k value and presents the detailed ridge regression results. Finally it shows three sets of graphs consisting k versus variance inflation factors, regression coefficients and standard errors of them. |
| Authors: | Filiz Karadag [aut] (ORCID: <https://orcid.org/0000-0002-0116-7772>), Hakan Savas Sazak [aut] (ORCID: <https://orcid.org/0000-0001-6123-1214>), Olgun Aydin [cre] (ORCID: <https://orcid.org/0000-0002-7090-0931>) |
| Maintainer: | Olgun Aydin <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-05-13 06:21:00 UTC |
| Source: | https://github.com/filizkrdg/ridgregextra |
Ridge regression with a manually selected k value
ridge_reg(x, y, k)ridge_reg(x, y, k)
x |
Explanatory variables (Dataframe, matrix) |
y |
Dependent variables (Dataframe, vector) |
k |
Ridge parameter |
A list of lists
library("mctest") x <- Hald[,-1] y <- Hald[,1] k <- 0.1 ridge_reg(x,y,k) library(isdals) data(bodyfat) x <- bodyfat[,-1] y <- bodyfat[,1] k <- 0.1 ridge_reg(x,y,k)library("mctest") x <- Hald[,-1] y <- Hald[,1] k <- 0.1 ridge_reg(x,y,k) library(isdals) data(bodyfat) x <- bodyfat[,-1] y <- bodyfat[,1] k <- 0.1 ridge_reg(x,y,k)
Ridge regression with a selected k value
ridgereg_k(x, y, a, b)ridgereg_k(x, y, a, b)
x |
Explanatory variables (Dataframe, matrix) |
y |
Dependent variables (Dataframe, vector) |
a |
Lower bound of k |
b |
Upper bound of k |
A list of lists
library("mctest") x <- Hald[,-1] y <- Hald[,1] ridgereg_k(x,y,a=0,b=1) library(isdals) data(bodyfat) x <- bodyfat[,-1] y <- bodyfat[,1] ridgereg_k(x,y,a=0,b=1)library("mctest") x <- Hald[,-1] y <- Hald[,1] ridgereg_k(x,y,a=0,b=1) library(isdals) data(bodyfat) x <- bodyfat[,-1] y <- bodyfat[,1] ridgereg_k(x,y,a=0,b=1)
Ridge regression tables in the range of given lower and upper bounds of k values
vif_k(x, y, a, b)vif_k(x, y, a, b)
x |
Explanatory variables (Dataframe, matrix) |
y |
Dependent variables (Dataframe, vector) |
a |
Lower bound of k |
b |
Upper bound of k |
A list of lists
library("mctest") x <- Hald[,-1] y <- Hald[,1] vif_k(x,y,a=0,b=1) library(isdals) data(bodyfat) x <- bodyfat[,-1] y <- bodyfat[,1] vif_k(x,y,a=0,b=1)library("mctest") x <- Hald[,-1] y <- Hald[,1] vif_k(x,y,a=0,b=1) library(isdals) data(bodyfat) x <- bodyfat[,-1] y <- bodyfat[,1] vif_k(x,y,a=0,b=1)